``pulp_rpm`` Plugin
===================

.. figure:: https://github.com/pulp/pulp_rpm/workflows/Pulp%20CI/badge.svg
   :alt: Pulp CI

This is the ``pulp_rpm`` Plugin for `Pulp Project
3.0+ <https://pypi.python.org/pypi/pulpcore/>`__. This plugin provides support for RPM family
content types, similar to the ``pulp_rpm`` plugin for Pulp 2.

For more information, please see the `documentation
<https://docs.pulpproject.org/pulp_rpm/>`_ or the `Pulp project page
<https://pulpproject.org>`_.


How to File an Issue
--------------------

`New pulp_rpm issue <https://pulp.plan.io/projects/pulp_rpm/issues/new>`_.

.. warning::
  Is this security related? If so, please follow the `Security Disclosures <https://docs.pulpproject.org/pulpcore/bugs-features.html#security-bugs>`_ procedure.

Please set **only the fields in this table**. See `Redmine Fields <https://docs.pulpproject.org/pulpcore/bugs-features.html#redmine-fields>`_ for more detailed
descriptions of all the fields and how they are used.

.. list-table::
   :header-rows: 1
   :widths: auto
   :align: center

   * - Field
     - Instructions

   * - Tracker
     - For a bug, select ``Issue``, for a feature-request, choose ``Story``,
       for a backport request, choose ``Backport``.

   * - Subject
     - Strive to be specific and concise.

   * - Description
     - This is the most important part! Please see `Description Field <https://docs.pulpproject.org/pulpcore/bugs-features.html#issue-description>`_.

   * - Version
     - The version of pulp_rpm that you discovered the issue.

   * - OS
     - Please select your operating system.
